==> react-bootstrap-0.2.0.tgz: package/es/components/List/Item.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Button from '../Button';
import Icon from '../Icon';

import colors from '../../utils/colors';

// Class based component instead stateless functional, because refs needed.
// eslint-disable-next-line react/prefer-stateless-function
var Item = (_temp = _class = function (_Component) {
  _inherits(Item, _Component);

  function Item() {
    _classCallCheck(this, Item);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Item.prototype.render = function render() {
    var _cn;

    var _props = this.props,
        Tag = _props.tag,
        color = _props.color,
        active = _props.active,
        clickable = _props.clickable,
        disabled = _props.disabled,
        className = _props.className,
        onClick = _props.onClick,
        onToggle = _props.onToggle,
        toggleIconName = _props.toggleIconName,
        innerRef = _props.innerRef,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['tag', 'color', 'active', 'clickable', 'disabled', 'className', 'onClick', 'onToggle', 'toggleIconName', 'innerRef', 'children']);

    return React.createElement(
      Tag,
      _extends({}, typeof onClick === 'function' ? { role: 'presentation', onClick: onClick } : {}, props, {
        ref: typeof innerRef === 'function' ? innerRef : undefined,
        className: cn('list-group-item', (_cn = {}, _cn['list-group-item-' + color] = color, _cn['list-group-item-action'] = typeof onClick === 'function' || clickable, _cn.toggled = typeof onToggle === 'function', _cn.active = active, _cn.disabled = disabled, _cn), className)
      }),
      typeof onToggle === 'function' ? React.createElement(
        Button,
        {
          color: active ? 'primary' : 'link',
          disabled: disabled,
          className: 'list-group-item-toggle',
          onClick: onToggle
        },
        React.createElement(Icon, { name: toggleIconName })
      ) : null,
      children
    );
  };

  return Item;
}(Component), _class.defaultProps = {
  tag: 'li',
  color: '',
  active: false,
  clickable: false,
  disabled: false,
  className: '',
  onClick: null,
  onToggle: null,
  toggleIconName: 'plus',
  innerRef: null,
  children: null
}, _temp);
Item.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  color: PropTypes.oneOf([''].concat(colors)),
  active: PropTypes.bool,
  clickable: PropTypes.bool,
  disabled: PropTypes.bool,
  className: PropTypes.string,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  toggleIconName: PropTypes.string,
  innerRef: PropTypes.func,
  children: PropTypes.node
} : {};


export default Item;

==> react-bootstrap-0.3.0.tgz: package/es/components/List/Item.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import colors from '../../utils/colors';

import Button from '../Button';
import Icon from '../Icon';

// Class based component instead stateless functional, because refs needed.
// eslint-disable-next-line react/prefer-stateless-function
var Item = (_temp = _class = function (_Component) {
  _inherits(Item, _Component);

  function Item() {
    _classCallCheck(this, Item);

    return _possibleConstructorReturn(this, _Component.apply(this, arguments));
  }

  Item.prototype.render = function render() {
    var _cn;

    var _props = this.props,
        Tag = _props.tag,
        color = _props.color,
        active = _props.active,
        clickable = _props.clickable,
        disabled = _props.disabled,
        onClick = _props.onClick,
        onToggle = _props.onToggle,
        toggleIconName = _props.toggleIconName,
        innerRef = _props.innerRef,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['tag', 'color', 'active', 'clickable', 'disabled', 'onClick', 'onToggle', 'toggleIconName', 'innerRef', 'children']);

    return React.createElement(
      Tag,
      _extends({}, typeof onClick === 'function' ? { role: 'presentation', onClick: onClick } : {}, props, {
        ref: typeof innerRef === 'function' ? innerRef : undefined,
        className: cn('list-group-item', (_cn = {}, _cn['list-group-item-' + color] = color, _cn['list-group-item-action'] = typeof onClick === 'function' || clickable, _cn.toggled = typeof onToggle === 'function', _cn.active = active, _cn.disabled = disabled, _cn), props.className)
      }),
      typeof onToggle === 'function' ? React.createElement(
        Button,
        {
          color: active ? 'primary' : 'link',
          disabled: disabled,
          className: 'list-group-item-toggle',
          onClick: onToggle
        },
        React.createElement(Icon, { name: toggleIconName })
      ) : null,
      children
    );
  };

  return Item;
}(Component), _class.defaultProps = {
  tag: 'li',
  color: '',
  active: false,
  clickable: false,
  disabled: false,
  onClick: null,
  onToggle: null,
  toggleIconName: 'plus',
  innerRef: null,
  children: null
}, _class.displayName = 'List.Item', _temp);
Item.propTypes = process.env.NODE_ENV !== "production" ? {
  tag: PropTypes.oneOfType([PropTypes.func, PropTypes.string]),
  color: PropTypes.oneOf([''].concat(colors)),
  active: PropTypes.bool,
  clickable: PropTypes.bool,
  disabled: PropTypes.bool,
  onClick: PropTypes.func,
  onToggle: PropTypes.func,
  toggleIconName: PropTypes.string,
  innerRef: PropTypes.func,
  children: PropTypes.node
} : {};


export default Item;
